abacusai.nested_feature — AbacusAI documentation

# abacusai.nested_feature

## Classes

`NestedFeature` | A nested feature in a feature group

## Module Contents

class abacusai.nested_feature.NestedFeature(client, name=None, selectClause=None, featureType=None, featureMapping=None, dataType=None, sourceTable=None, originalName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A nested feature in a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column

    - selectClause (str) – The sql logic for creating this feature’s data

    - featureType (str) – Feature Type of the Feature

    - featureMapping (str) – The Feature Mapping of the feature

    - dataType (str) – Data Type of the Feature

    - sourceTable (str) – The source table of the column

    - originalName (str) – The original name of the column

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict